package foo;
import java.util.Collection;
import java.util.List;
import javax.annotation.Resource;
import javax.faces.application.FacesMessage;
import javax.faces.context.ExternalContext;
import javax.faces.context.FacesContext;
import javax.faces.model.SelectItem;
import javax.persistence.EntityManager;
import javax.persistence.PersistenceContext;
import javax.servlet.http.HttpServletRequest;
import javax.transaction.UserTransaction;

public class CustomerController {

    private Customer customer;

    @Resource
    private UserTransaction utx;

    @PersistenceContext(unitName = "WebApplication21")
    private EntityManager em;

    public String createSetup() {
        this.customer = new Customer();
        return "customer_create";
    }

    public String create() {
        try {
            utx.begin();
            em.persist(customer);
            utx.commit();
        } catch (Exception ex) {
            try {
                utx.rollback();
            } catch (Exception e) {}
        }
        addMessage("Customer was successfully created.");
        return "customer_list"; 
    }

    public String detailSetup() {
        setCustomerFromRequestParam();
        return "customer_detail";
    }

    public String editSetup() {
        setCustomerFromRequestParam();
        return "customer_edit";
    }

    public String edit() {
        try {
            utx.begin();
            customer = em.merge(customer);
            utx.commit();
            addMessage("Customer was successfully updated.");
        } catch (Exception ex) {
            try {
                utx.rollback();
            } catch (Exception e) {}
        }
        return "customer_list"; 
    }

    public String destroy() {
        try {
            utx.begin();
            Customer customer = getCustomerFromRequestParam();
            customer = em.merge(customer);
            em.remove(customer);
            utx.commit();
            addMessage("Customer was successfully deleted.");
        } catch (Exception ex) {
            try {
                utx.rollback();
            } catch (Exception e) {}
        }
        return "customer_list"; 
    }

    public Customer getCustomerFromRequestParam() {
        ExternalContext ec = FacesContext.getCurrentInstance().getExternalContext();
        HttpServletRequest request = (HttpServletRequest)ec.getRequest();
        String param = request.getParameter("customerId");
        Integer id = new Integer(param);
        return em.find(Customer.class, id);
    }

    public void setCustomerFromRequestParam() {
        Customer customer = getCustomerFromRequestParam();
        setCustomer(customer);
    }

    public Collection getCustomers() {
        return em.createQuery("select object(o) from Customer as o").getResultList();
    }

    public Customer getCustomer() {
        return customer;
    }

    public void setCustomer(Customer customer) {
        this.customer = customer;
    }

    public static void addMessage(String msg) {
        FacesMessage facesMsg = new FacesMessage(FacesMessage.SEVERITY_ERROR, msg, msg);
        FacesContext fc = FacesContext.getCurrentInstance();
        fc.addMessage(null, facesMsg);
    }

    public Customer findCustomer(Integer id) {
        return (Customer) em.find(Customer.class, id);
    }

    public javax.faces.model.SelectItem[] getDiscountCodes() {
        List <DiscountCode> l = (List <DiscountCode>) em.createQuery("select o from DiscountCode as o").getResultList();
        SelectItem select[] = new SelectItem[l.size()];
        int i = 0;
        for(DiscountCode x : l) {
                select[i++] = new SelectItem(x);
            }
            return select;
    }
}
