package foo;
import java.util.Collection;
import java.util.List;
import javax.annotation.Resource;
import javax.faces.application.FacesMessage;
import javax.faces.context.ExternalContext;
import javax.faces.context.FacesContext;
import javax.faces.model.SelectItem;
import javax.persistence.EntityManager;
import javax.persistence.PersistenceContext;
import javax.servlet.http.HttpServletRequest;
import javax.transaction.UserTransaction;

public class ProductController {

    private Product product;

    @Resource
    private UserTransaction utx;

    @PersistenceContext(unitName = "WebApplication21")
    private EntityManager em;

    public String createSetup() {
        this.product = new Product();
        return "product_create";
    }

    public String create() {
        try {
            utx.begin();
            em.persist(product);
            utx.commit();
        } catch (Exception ex) {
            try {
                utx.rollback();
            } catch (Exception e) {}
        }
        addMessage("Product was successfully created.");
        return "product_list"; 
    }

    public String detailSetup() {
        setProductFromRequestParam();
        return "product_detail";
    }

    public String editSetup() {
        setProductFromRequestParam();
        return "product_edit";
    }

    public String edit() {
        try {
            utx.begin();
            product = em.merge(product);
            utx.commit();
            addMessage("Product was successfully updated.");
        } catch (Exception ex) {
            try {
                utx.rollback();
            } catch (Exception e) {}
        }
        return "product_list"; 
    }

    public String destroy() {
        try {
            utx.begin();
            Product product = getProductFromRequestParam();
            product = em.merge(product);
            em.remove(product);
            utx.commit();
            addMessage("Product was successfully deleted.");
        } catch (Exception ex) {
            try {
                utx.rollback();
            } catch (Exception e) {}
        }
        return "product_list"; 
    }

    public Product getProductFromRequestParam() {
        ExternalContext ec = FacesContext.getCurrentInstance().getExternalContext();
        HttpServletRequest request = (HttpServletRequest)ec.getRequest();
        String param = request.getParameter("productId");
        Integer id = new Integer(param);
        return em.find(Product.class, id);
    }

    public void setProductFromRequestParam() {
        Product product = getProductFromRequestParam();
        setProduct(product);
    }

    public Collection getProducts() {
        return em.createQuery("select object(o) from Product as o").getResultList();
    }

    public Product getProduct() {
        return product;
    }

    public void setProduct(Product product) {
        this.product = product;
    }

    public static void addMessage(String msg) {
        FacesMessage facesMsg = new FacesMessage(FacesMessage.SEVERITY_ERROR, msg, msg);
        FacesContext fc = FacesContext.getCurrentInstance();
        fc.addMessage(null, facesMsg);
    }

    public Product findProduct(Integer id) {
        return (Product) em.find(Product.class, id);
    }

    public javax.faces.model.SelectItem[] getManufactureIds() {
        List <Manufacture> l = (List <Manufacture>) em.createQuery("select o from Manufacture as o").getResultList();
        SelectItem select[] = new SelectItem[l.size()];
        int i = 0;
        for(Manufacture x : l) {
                select[i++] = new SelectItem(x);
            }
            return select;
    }

    public javax.faces.model.SelectItem[] getProductCodes() {
        List <ProductCode> l = (List <ProductCode>) em.createQuery("select o from ProductCode as o").getResultList();
        SelectItem select[] = new SelectItem[l.size()];
        int i = 0;
        for(ProductCode x : l) {
                select[i++] = new SelectItem(x);
            }
            return select;
    }
}
